==> igniteui-react-core-16.15.1.tgz: package/esm5/lib/TextColumnDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnDescriptionMetadata } from "./ColumnDescriptionMetadata";
import { TextColumnDescription } from "./TextColumnDescription";
/**
 * @hidden
 */
var TextColumnDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TextColumnDescriptionMetadata, _super);
    function TextColumnDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TextColumnDescriptionMetadata.b = function (a) {
        if (TextColumnDescriptionMetadata.a == null) {
            TextColumnDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TextColumnDescriptionMetadata.c(TextColumnDescriptionMetadata.a);
        }
        if (a.g(TextColumnDescriptionMetadata.a)) {
            return;
        }
        a.s(TextColumnDescriptionMetadata.a);
    };
    TextColumnDescriptionMetadata.c = function (a) {
        ColumnDescriptionMetadata.c(a);
        a.item("EditorType", "ExportedType:string:EditorType");
        a.item("EditorType@names", "Default;Text;Numeric;Date;Combo");
        a.item("EditorDataSourceRef", "(w:EditorItemsSource,xam:EditorItemsSource,wf:EditorItemsSource)DataRef::object");
        a.item("EditorDataSource", "(w:EditorItemsSource,xam:EditorItemsSource,wf:EditorItemsSource)ExportedType:BaseDataSource:BaseDataSource");
        a.item("EditorTextField", "String");
        a.item("EditorValueField", "Array:string");
    };
    TextColumnDescriptionMetadata.d = function (a) {
        TextColumnDescriptionMetadata.b(a);
        a.u("TextColumn", function () { return new TextColumnDescription(); });
        a.t("TextColumn", TextColumnDescriptionMetadata.a);
    };
    TextColumnDescriptionMetadata.$t = markType(TextColumnDescriptionMetadata, 'TextColumnDescriptionMetadata');
    TextColumnDescriptionMetadata.a = null;
    return TextColumnDescriptionMetadata;
}(Base));
export { TextColumnDescriptionMetadata };

==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/TextColumnDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnDescriptionMetadata } from "./ColumnDescriptionMetadata";
import { TextColumnDescription } from "./TextColumnDescription";
/**
 * @hidden
 */
var TextColumnDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TextColumnDescriptionMetadata, _super);
    function TextColumnDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TextColumnDescriptionMetadata.b = function (a) {
        if (TextColumnDescriptionMetadata.a == null) {
            TextColumnDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TextColumnDescriptionMetadata.c(TextColumnDescriptionMetadata.a);
        }
        if (a.g(TextColumnDescriptionMetadata.a)) {
            return;
        }
        a.s(TextColumnDescriptionMetadata.a);
    };
    TextColumnDescriptionMetadata.c = function (a) {
        ColumnDescriptionMetadata.c(a);
        a.item("EditorType", "ExportedType:string:EditorType");
        a.item("EditorType@names", "Default;Text;Numeric;Date;Combo");
        a.item("EditorDataSourceRef", "(w:EditorItemsSource,xam:EditorItemsSource,wf:EditorItemsSource)DataRef::object");
        a.item("EditorDataSource", "(w:EditorItemsSource,xam:EditorItemsSource,wf:EditorItemsSource)ExportedType:BaseDataSource:BaseDataSource");
        a.item("EditorTextField", "String");
        a.item("EditorValueField", "String");
    };
    TextColumnDescriptionMetadata.d = function (a) {
        TextColumnDescriptionMetadata.b(a);
        a.u("TextColumn", function () { return new TextColumnDescription(); });
        a.t("TextColumn", TextColumnDescriptionMetadata.a);
    };
    TextColumnDescriptionMetadata.$t = markType(TextColumnDescriptionMetadata, 'TextColumnDescriptionMetadata');
    TextColumnDescriptionMetadata.a = null;
    return TextColumnDescriptionMetadata;
}(Base));
export { TextColumnDescriptionMetadata };
